# BooleanFunctions
Boolean Function research for boolean functions on five variables.

For best viewing experience, it is recommended that [TeX All the Things](https://chrome.google.com/webstore/detail/tex-all-the-things/cbimabofgmfdkicghcadidpemeenbffn?hl=en) is installed.
